# Test Coverage Report

Generated: Mon 2013-04-29 18:13 CST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 284 | 175 | 48 | 74.2%
auction.__init__ | 1 | 0 | 0 | 0.0%
auction.context_processors | 6 | 0 | 1 | 0.0%
auction.forms | 17 | 0 | 4 | 0.0%
auction.models.__init__ | 4 | 0 | 4 | 100.0%
auction.models.auctionmodel | 5 | 2 | 3 | 100.0%
auction.models.bases | 125 | 105 | 17 | 97.2%
auction.models.bidbasket | 5 | 2 | 3 | 100.0%
auction.models.biditem | 5 | 2 | 3 | 100.0%
auction.models.defaults | 27 | 24 | 3 | 100.0%
auction.models.lot | 5 | 2 | 3 | 100.0%
auction.utils.generic | 31 | 22 | 4 | 81.5%
auction.utils.loader | 53 | 16 | 3 | 32.0%

Excluded packages and modules
Error packages and modules